@@ -1,3 +1,26 @@
+##############################################################################
+#    Copyright (c) 2012-2016 Russell V. Lenth                                #
+#                                                                            #
+#    This file is part of the lsmeans package for R (*lsmeans*)              #
+#                                                                            #
+#    *lsmeans* is free software: you can redistribute it and/or modify       #
+#    it under the terms of the GNU General Public License as published by    #
+#    the Free Software Foundation, either version 2 of the License, or       #
+#    (at your option) any later version.                                     #
+#                                                                            #
+#    *lsmeans* is distributed in the hope that it will be useful,            #
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
+#    GNU General Public License for more details.                            #
+#                                                                            #
+#    You should have received a copy of the GNU General Public License       #
+#    along with R and *lsmeans*.  If not, see                                #
+#    <https://www.r-project.org/Licenses/> and/or                            #
+#    <http://www.gnu.org/licenses/>.                                         #
+##############################################################################
+
+# lsmeans and related functions
+
 # Utility to pick out the args that can be passed to a function
 .args.for.fcn = function(fcn, args) {
     oknames = names(as.list(args(fcn)))
@@ -107,20 +130,42 @@ lsmeans.list = function(object, specs, ...) {
 
 # Generic for after we've gotten specs in character form
 lsmeans.character = function(object, specs, ...) {
-    UseMethod("lsmeans.character")####, object)
+    UseMethod("lsmeans.character")
 }
 
 # Needed for model objects
-lsmeans.character.default = function(object, specs, ...)
-    lsmeans.default(object, specs, ...)
+lsmeans.character.default = function(object, specs, trend, ...) {
+    if (!missing(trend))
+        lstrends(object, specs, var = trend, ...)
+    else
+        lsmeans.default(object, specs, ...)
+}
 
 # Method for a ref.grid -- all methods will get us here eventually
 lsmeans.character.ref.grid = function(object, specs, by = NULL, 
          fac.reduce = function(coefs) apply(coefs, 2, mean), 
-         contr, options = getOption("lsmeans")$lsmeans, weights, ...) {
+         contr, options = getOption("lsmeans")$lsmeans, weights, trend, ...) {
+    
+    if (!missing(trend)) {
+        stop("Trend results require supplying the model object itself, not a reference grid")
+        # message("Re-fitting the model. Avoid this by calling lsmeans with the model object.")
+        # cl = match.call()
+        # cl[[1]] = as.name("lstrends")
+        # cl$model = object@model.info$call
+        # cl$var = trend
+        # cl$object = cl$trend = NULL
+        # return(eval(cl))
+    }
+    
     RG = object
     facs = union(specs, by)
     
+    if ((length(facs) == 1) && (facs == "1")) {  ### just want grand mean
+        RG@levels[["1"]] = "overall"
+        RG@grid[ ,"1"] = 1
+    }
+    
+    
     # Figure out the structure of the grid
     wgt = RG@grid[[".wgt."]]
     if(all(zapsmall(wgt) == 0)) wgt = wgt + 1 ### repl all zero wgts with 1
@@ -182,7 +227,7 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
     levs = list()
     for (f in facs) {
         levs[[f]] = RG@levels[[f]]
-        if (is.null(levs[[f]]))
+        if (!hasName(levs, f))
             stop(paste("No variable named", f, "in the reference grid"))
     }
     combs = do.call("expand.grid", levs)
@@ -203,7 +248,7 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
         message("NOTE: Results may be misleading due to involvement in interactions")
     
     # Figure offset, if any
-    if (".offset." %in% names(RG@grid)) {
+    if (hasName(RG@grid, ".offset.")) {
         combs[[".offset."]] = as.numeric(plyr::aaply(row.idx, use.mars, function(idx)
             fac.reduce(as.matrix(RG@grid[idx, ".offset.", drop=FALSE]))))
     }
@@ -243,7 +288,7 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
         # TO DO: provide for passing dots to cld                
             return(cld(result, by = by))
         }
-        ctrs = contrast(result, method = contr, by, ...)
+        ctrs = contrast(result, method = contr, by = by, ...)
         .cls.list("lsm.list", lsmeans = result, contrasts = ctrs)
     }
 }
@@ -262,13 +307,47 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
 contrast = function(object, ...)
     UseMethod("contrast")
 
-contrast.ref.grid = function(object, method = "eff", by, adjust, offset = NULL,
-        name = "contrast", options = getOption("lsmeans")$contrast, ...) {
+contrast.ref.grid = function(object, method = "eff", interaction = FALSE, 
+        by, offset = NULL, name = "contrast", 
+        options = getOption("lsmeans")$contrast, adjust, ...) 
+{
+    if(missing(by)) 
+        by = object@misc$by.vars
+    if(length(by) == 0) # character(0) --> NULL
+        by = NULL
+
+    if (is.logical(interaction) && interaction)
+        interaction = method
+    if (!is.logical(interaction)) { # i.e., interaction is not FALSE
+        if (!is.character(interaction))
+            stop("interaction requires named contrast function(s)")
+        if(missing(adjust))
+            adjust = "none"
+        by = NULL
+        vars = names(object@levels)
+        k = length(vars)
+        if(!is.null(by)) {
+            vars = c(setdiff(vars, by), by)
+            k = k - length(by)
+        }
+        interaction = rep(interaction, k)[1:k]
+        for (i in k:1) {
+            nm = paste(vars[i], interaction[i], sep = "_")
+            object = contrast.ref.grid(object, interaction[i], by = vars[-i], name = nm)
+            vars[i] = nm
+        }
+        object = update(object, by = by, adjust = adjust, ...)
+        if(!is.null(options)) {
+            options$object = object
+            object = do.call(update.ref.grid, options)
+        }
+        return(object)
+    }
+    
+    # else
     args = object@grid
     args[[".offset."]] = NULL 
     args[[".wgt."]] = NULL # ignore auxiliary stuff in labels, etc.
-    if(missing(by)) 
-        by = object@misc$by.vars
     if (!is.null(by)) {
         by.rows = .find.by.rows(args, by)
         bylevs = args[, by, drop=FALSE]
@@ -300,13 +379,16 @@ contrast.ref.grid = function(object, method = "eff", by, adjust, offset = NULL,
     cmat = method(levs, ...)
     if (!is.data.frame(cmat))
         stop("Contrast function must provide a data.frame")
+    else if(ncol(cmat) == 0)
+        warning("No contrasts were generated! Perhaps only one lsmean is involved.\n",
+             "  This can happen, for example, when your predictors are not factors.")
     else if (nrow(cmat) != nrow(args))
         stop("Nonconforming number of contrast coefficients")
     
     if (is.null(by)) {
         linfct = t(cmat) %*% object@linfct
         grid = data.frame(.contrast.=names(cmat))
-        if (".offset." %in% names(object@grid))
+        if (hasName(object@grid, ".offset."))
             grid[[".offset."]] = t(cmat) %*% object@grid[[".offset."]]
     }
     
@@ -325,7 +407,7 @@ contrast.ref.grid = function(object, method = "eff", by, adjust, offset = NULL,
         for (v in by)
             xlevs[[v]] = rep(bylevs[row.1st, v], each=n.each)
         grid = cbind(grid, as.data.frame(xlevs))
-        if (".offset." %in% names(object@grid))
+        if (hasName(object@grid, ".offset."))
             grid[[".offset."]] = tcmat %*% object@grid[unlist(by.rows), ".offset."]
     }
     
@@ -340,6 +422,7 @@ contrast.ref.grid = function(object, method = "eff", by, adjust, offset = NULL,
     
     row.names(linfct) = NULL
     misc = object@misc
+    misc$initMesg = NULL # initial annotation likely will no longer apply
     misc$estName = "estimate"
     if (!is.null(et <- attr(cmat, "type")))
         misc$estType = et
@@ -355,9 +438,9 @@ contrast.ref.grid = function(object, method = "eff", by, adjust, offset = NULL,
     if (!is.null(attr(cmat, "offset")))
         offset = attr(cmat, "offset")
     if (!is.null(offset)) {
-        if(is.null(grid[[".offset."]]))
+        if(!hasName(grid, ".offset."))
             grid[[".offset."]] = 0
-            grid[[".offset."]] = grid[[".offset."]] + rep(offset, length(by.rows))
+        grid[[".offset."]] = grid[[".offset."]] + rep(offset, length(by.rows))
     }
     misc$adjust = adjust
     misc$infer = c(FALSE, TRUE)
@@ -365,18 +448,34 @@ contrast.ref.grid = function(object, method = "eff", by, adjust, offset = NULL,
     # zap the transformation info except in very special cases
     if (!is.null(misc$tran)) {
         misc$orig.tran = misc$tran
-        # anything other than (-1,0,1)?
-        non.comp = setdiff(zapsmall(unique(as.matrix(cmat))), c(-1,0,1)) 
-        if(length(non.comp) == 0 && (misc$tran %in% c("log", "logit"))) {
+# --- previous code        
+#         # anything other than (-1,0,1)?
+#         non.comp = setdiff(zapsmall(unique(as.matrix(cmat))), c(-1,0,1)) 
+#         if(length(non.comp) == 0 && (misc$tran %in% c("log", "logit"))) {
+#             misc$orig.inv.lbl = misc$inv.lbl
+#             misc$inv.lbl = ifelse(misc$tran == "logit", "odds.ratio", 
+#                                   paste(misc$inv.lbl,"ratio",sep="."))
+#             misc$tran = "log"
+#         }
+# Replacement 2016-10-19:
+        true.con = all(zapsmall(apply(cmat, 2, sum)) == 0) # each set of coefs sums to 0
+        if (true.con && misc$tran == "log") {
             misc$orig.inv.lbl = misc$inv.lbl
-            misc$inv.lbl = ifelse(misc$tran == "logit", "odds.ratio", 
-                                  paste(misc$inv.lbl,"ratio",sep="."))
+            misc$inv.lbl = paste(misc$inv.lbl,"ratio",sep=".")
             misc$tran = "log"
         }
+        else if (true.con && misc$tran == "logit") {
+            misc$orig.inv.lbl = misc$inv.lbl
+            misc$inv.lbl = "odds.ratio"
+            misc$tran = "log.o.r."
+        }
         else
-            misc$tran = NULL
+            misc$tran = misc$tran.mult = NULL
     }
     
+    # ensure we don't inherit inappropriate settings
+    misc$null = misc$delta = misc$side = NULL
+    
     object@roles$predictors = "contrast"
     levels = list()
     for (nm in setdiff(names(grid), ".offset."))
@@ -435,7 +534,13 @@ test.ref.grid = function(object, null = 0,
             print(cbind(object@grid, equals = null))
         } 
         L = object@linfct
-        if (!missing(rows))
+        bhat = object@bhat
+        estble.idx = which(!is.na(object@bhat))
+        bhat = bhat[estble.idx]
+        est.flag = !is.na(object@nbasis[1])
+        
+        ### L = L[, estble.idx, drop = FALSE]
+         if (!missing(rows))
             by.rows = list(sel.rows = rows)
         else {
             by.rows = list(all = seq_len(nrow(L)))
@@ -445,44 +550,53 @@ test.ref.grid = function(object, null = 0,
                 by.rows = .find.by.rows(object@grid, by)
         }
         
-        estble.idx = which(!is.na(object@bhat))
-        bhat = object@bhat[estble.idx]
-        ###L = L[, estble.idx, drop = FALSE]
-        lindep = FALSE
-        
+        lindep = nonest = FALSE
+
         result = lapply(by.rows, function(rows) {
             LL = L[rows, , drop = FALSE]
-            if (!all(is.estble(LL, object@nbasis)))
-                c(F = NA, df1 = NA, df2 = NA, p.value = NA)
-            else {
-                LL = LL[, estble.idx, drop = FALSE]
-                # Check rank
-                qrLt = qr(t(LL))
-                r = qrLt$rank
-                if (r < nrow(LL)) {
-                    if(!all(null==0))
-                        stop("Rows are linearly dependent - cannot do the test when 'null' != 0")
-                    else
-                        lindep <<- TRUE
-                }
-                tR = t(qr.R(qrLt))[1:r,1:r]
-                tQ = t(qr.Q(qrLt))[1:r, , drop = FALSE]
-                if(length(null) < r) null = rep(null,r)
-                z = tQ %*% bhat - solve(tR, null[1:r])
-                zcov = tQ %*% object@V %*% t(tQ)
-                F = sum(z * solve(zcov, z)) / r
-                df2 = object@dffun(tQ, object@dfargs)
-                if (is.na(df2))
-                    p.value = pchisq(F*r, r, lower.tail = FALSE)
-                else
-                    p.value = pf(F, r, df2, lower.tail = FALSE)
-                round(c(F = F, df1 = r, df2 = df2, p.value = p.value), 4)
+            # estract est'ble rows
+            if(est.flag) {
+                erows = estimability::is.estble(LL, object@nbasis)
+                nonest <<- nonest || (sum(erows) < nrow(LL))
+                LL = LL[erows, estble.idx, drop = FALSE]
             }
+            # Check rank
+            qrLt = qr(t(LL)) # this will work even if LL has 0 rows
+            r = qrLt$rank
+            if (r == 0)
+                return(c(df1 = 0, df2 = NA, F = NA, p.value = NA))
+            if (r < nrow(LL)) {
+                if(!all(null == 0))
+                    stop("Rows are linearly dependent - cannot do the test when 'null' != 0")
+                else 
+                    lindep <<- TRUE
+            }
+            tR = t(qr.R(qrLt))[1:r, 1:r, drop = FALSE]
+            tQ = t(qr.Q(qrLt))[1:r, , drop = FALSE]
+            if(length(null) < r) null = rep(null, r)
+            z = tQ %*% bhat - solve(tR, null[1:r])
+            zcov = tQ %*% object@V %*% t(tQ)
+            F = sum(z * solve(zcov, z)) / r
+            df2 = object@dffun(tQ, object@dfargs)
+            if (is.na(df2))
+                p.value = pchisq(F*r, r, lower.tail = FALSE)
+            else
+                p.value = pf(F, r, df2, lower.tail = FALSE)
+            c(round(c(df1 = r, df2 = df2), 2), F = round(F, 3), p.value = p.value)
         })
         
+        result = as.data.frame(t(as.data.frame(result)))
+        if (!missing(by)) {
+            fbr = sapply(by.rows, "[", 1)
+            result = cbind(object@grid[fbr, by, drop = FALSE], result)
+        }
+        class(result) = c("summary.ref.grid", "data.frame")
         if (lindep)
-            message("Note: Rows are linearly dependent - df are reduced accordingly")
-        t(as.data.frame(result))
+            message("There are linearly dependent rows - df are reduced accordingly")
+        if (nonest)
+            message("Some rows are non-estimable and were excluded")
+        
+        result
     }
 }
 
@@ -497,88 +611,6 @@ pairs.ref.grid = function(x, reverse = FALSE, ...) {
 
 
 
-### lstrends function
-lstrends = function(model, specs, var, delta.var=.01*rng, data, ...) {
-    estName = paste(var, "trend", sep=".") # Do now as I may replace var later
-
-    if (missing(data)) {
-        data = try(recover.data (model, data = NULL))
-        if (inherits(data, "try-error"))
-            stop("Possible remedy: Supply the data used in the 'data' argument")
-    }
-    else # attach needed attributes to given data
-        data = recover.data(model, data = data)
-    
-    x = data[[var]]
-    fcn = NULL   # differential
-    if (is.null(x)) {
-        fcn = var
-        var = .all.vars(as.formula(paste("~",var)))
-        if (length(var) > 1)
-            stop("Can only support a function of one variable")
-        else {
-            x = data[[var]]
-            if (is.null(x)) stop("Variable '", var, "' is not in the dataset")            
-        }
-    }
-    rng = diff(range(x))
-    if (delta.var == 0)  stop("Provide a nonzero value of 'delta.var'")
-    
-    RG = ref.grid(model, data = data, ...)
-    grid = RG@grid
-    if (!is.null(mr <- RG@roles$multresp)) {
-        # use the grid value only for the 1st mult resp (no dupes)
-        if (length(mr) > 0)
-            grid = grid[grid[[mr]] == RG@levels[[mr]][1], ]
-    }
-    grid[[var]] = grid[[var]] + delta.var
-    
-    basis = lsm.basis(model, attr(data, "terms"), RG@roles$xlev, grid, ...)
-    if (is.null(fcn))
-        newlf = (basis$X - RG@linfct) / delta.var
-    else {
-        y0 = with(RG@grid, eval(parse(text = fcn)))
-        yh = with(grid, eval(parse(text = fcn)))
-        diffl = (yh - y0)
-        if (any(diffl == 0)) warning("Some differentials are zero")
-        newlf = (basis$X - RG@linfct) / diffl
-    }
-    
-    # remove transformation from object
-    .zaptran = function(obj) {
-        if (is(obj, "ref.grid") && !is.null(obj@misc$tran)) {
-            obj@misc$orig.tran = result@misc$tran
-            obj@misc$tran = NULL
-        }
-        obj
-    }
-    
-    RG@linfct = newlf
-    RG@roles$trend = var
-    args = list(object=RG, specs=specs, ...)
-    args$at = args$cov.reduce = args$mult.levs = args$vcov. = NULL
-    result = do.call("lsmeans", args)
-    if (is.list(result)) {
-        names(result)[1] = "lstrends"
-        if (is(result[[1]], "ref.grid")) {
-            result[[1]]@misc$estName = estName
-            result[[1]]@misc$estType = "prediction"
-            result[[1]]@misc$methDesc = "trends"
-            for (i in seq_along(result))
-                result[[i]] = .zaptran(result[[i]])
-        }
-    }
-    else {
-        result@misc$estName = estName
-        result@misc$estType = "prediction"
-        result@misc$methDesc = "trends"
-        result = .zaptran(result)
-    }
-    
-    
-    result
-}
-
 
 # Check if model contains a term containing all elts of facs
 # Note: if an lstrends call, we want to include trend var in facs
