@@ -1,3 +1,24 @@
+##############################################################################
+#    Copyright (c) 2012-2016 Russell V. Lenth                                #
+#                                                                            #
+#    This file is part of the lsmeans package for R (*lsmeans*)              #
+#                                                                            #
+#    *lsmeans* is free software: you can redistribute it and/or modify       #
+#    it under the terms of the GNU General Public License as published by    #
+#    the Free Software Foundation, either version 2 of the License, or       #
+#    (at your option) any later version.                                     #
+#                                                                            #
+#    *lsmeans* is distributed in the hope that it will be useful,            #
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
+#    GNU General Public License for more details.                            #
+#                                                                            #
+#    You should have received a copy of the GNU General Public License       #
+#    along with R and *lsmeans*.  If not, see                                #
+#    <https://www.r-project.org/Licenses/> and/or                            #
+#    <http://www.gnu.org/licenses/>.                                         #
+##############################################################################
+
 ### This file has summary.ref.grid S3 method and related functions
 
 # Computes the quadratic form y'Xy after subsetting for the nonzero elements of y
@@ -8,7 +29,6 @@
     else 0
 }
 
-
 # utility fcn to get est's, std errors, and df
 # new arg: do.se -- if FALSE, just do the estimates and return 0 for se and df
 # returns a data.frame with an add'l "link" attribute if misc$tran is non-null
@@ -17,7 +37,13 @@
 # 2.13: Revised to call w/ just object instead of all those args (except linfct)
 #   Also moved offset comps to here, and provided for misc$estHook
 .est.se.df = function(object, do.se=TRUE, tol = get.lsm.option("estble.tol")) {
+    if (nrow(object@grid) == 0) {
+        result = data.frame(NA, NA, NA)
+        names(result) = c(object@misc$estName, "SE", "df")
+        return(result[-1, ])
+    }
     misc = object@misc
+
     if (!is.null(hook <- misc$estHook)) {
         if (is.character(hook)) hook = get(hook)
         result = hook(object, do.se=do.se, tol=tol)
@@ -43,17 +69,31 @@
         if (!is.null(object@grid$.offset.))
             result[, 1] = result[, 1] + object@grid$.offset.
     }
+    result[1] = as.numeric(result[1]) # silly bit of code to avoid getting a data.frame of logicals if all are NA
     result = as.data.frame(result)
     names(result) = c(misc$estName, "SE", "df")
-    
+
     if (!is.null(misc$tran) && (misc$tran != "none")) {
-        if(is.character(misc$tran)) {
-            link = try(make.link(misc$tran), silent=TRUE)
-            if (!inherits(link, "try-error"))
-                attr(result, "link") = link
-        }
+        link = if(is.character(misc$tran))
+            .make.link(misc$tran)
         else if (is.list(misc$tran))
-            attr(result, "link") = misc$tran
+            misc$tran
+        else 
+            NULL
+        
+        if (is.list(link)) {  # See if multiple of link is requested
+            if (!is.null(misc$tran.mult))
+                link$mult = misc$tran.mult
+            if (!is.null(link$mult))
+                link = with(link, list(
+                    linkinv = function(eta) linkinv(eta / mult),
+                    mu.eta = function(eta) mu.eta(eta / mult) / mult,
+                    name = paste0(round(mult, 3), "*", name)))
+        }
+        
+        if (!is.null(link) && is.null(link$name))
+                link$name = "linear-predictor"
+        attr(result, "link") = link
     }
     result
 }
@@ -139,8 +179,9 @@
     adj.meths = c("sidak", "tukey", "scheffe", "dunnettx", "mvt", "bonferroni", "none")
     k = pmatch(tolower(adjust), adj.meths)
     if(is.na(k)) {
-        k = which(adj.meths == "none")
-        mesg = "Confidence levels are NOT adjusted for multiplicity"
+        k = which(adj.meths == "bonferroni") ###none")
+        ###mesg = paste("\"", adjust, "\" adjustment is not valid for CIs: used bonferroni instead", sep = "")
+        ###mesg = "Confidence levels are NOT adjusted for multiplicity"
     }
     adjust = adj.meths[k]
     if ((fam.info[3] != 3) && adjust == "tukey") # not pairwise
@@ -330,7 +371,39 @@ predict.ref.grid <- function(object, type, ...) {
 
 # S3 summary method
 summary.ref.grid <- function(object, infer, level, adjust, by, type, df, 
-                             null = 0, delta = 0, side = 0, ...) {
+                             null, delta, side, ...) {
+    ### For missing arguments, get from misc, else default    
+    if(missing(infer))
+        infer = object@misc$infer
+    if(missing(level))
+        level = object@misc$level
+    if(missing(adjust))
+        adjust = object@misc$adjust
+    if(missing(by))
+        by = object@misc$by.vars
+    
+    if (missing(type))
+        type = .get.predict.type(object@misc)
+    else
+        type = .validate.type(type)
+    
+    if(missing(df)) 
+        df = object@misc$df
+    if(!is.null(df))
+        object@dffun = function(k, dfargs) df
+    
+    # for missing args that default to zero unless provided or in misc slot
+    .nul.eq.zero = function(val) {
+        if(is.null(val)) 0
+        else val
+    }
+    if(missing(null))
+        null = .nul.eq.zero(object@misc$null)
+    if(missing(delta))
+        delta = .nul.eq.zero(object@misc$delta)
+    if(missing(side))
+        side = .nul.eq.zero(object@misc$side)
+    
     # update with any "summary" options
     opt = get.lsm.option("summary")
     if(!is.null(opt)) {
@@ -338,9 +411,6 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
         object = do.call("update.ref.grid", opt)
     }
     
-    if(missing(df)) df = object@misc$df
-    if(!is.null(df))
-        object@dffun = function(k, dfargs) df
     
     # reconcile all the different ways we could specify the alternative
     # ... and map each to one of the first 3 subscripts
@@ -355,35 +425,24 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
                      c(object@roles$responses, ".offset.", ".wgt."))
     lbls = object@grid[lblnms]
     
-    ### implement my 'variable defaults' scheme    
-    if(missing(infer)) infer = object@misc$infer
-    if(missing(level)) level = object@misc$level
-    if(missing(adjust)) adjust = object@misc$adjust
-    if(missing(by)) by = object@misc$by.vars
-    
-    if (missing(type))
-        type = .get.predict.type(object@misc)
-    else
-        type = .validate.type(type)
-    
     zFlag = (all(is.na(result$df)))
     inv = (type == "response") # flag to inverse-transform
-    
+    link = attr(result, "link")
+    if (inv && is.null(link))
+        inv = FALSE
+
     if ((length(infer) == 0) || !is.logical(infer)) 
         infer = c(FALSE, FALSE)
     if(length(infer == 1)) 
         infer = c(infer,infer)
     
     if(inv && !is.null(object@misc$tran)) {
-        link = attr(result, "link")
         if (!is.null(object@misc$inv.lbl))
             names(result)[1] = object@misc$inv.lbl
         else
             names(result)[1] = "lsresponse"
     }
-    else
-        link = NULL
-    
+
     attr(result, "link") = NULL
     estName = names(result)[1]
     
@@ -391,10 +450,13 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
     
     ### Add an annotation when we show results on lp scale and
     ### there is a transformation
-    if (!inv && !is.null(linkName <- object@misc$tran)) {
-        if (!is.character(linkName))
-            linkName = "linear predictor (not response)"
-        mesg = c(mesg, paste("Results are given on the", linkName, "scale."))
+    if (!inv && !is.null(link)) {
+        mesg = c(mesg, paste("Results are given on the", link$name, "(not the response) scale."))
+    }
+    if (inv && !is.null(link$unknown)) {
+        mesg = c(mesg, paste0('Unknown transformation "', link$name, '": no transformation done'))
+        inv = FALSE
+        link = NULL
     }
     
     # et = 1 if a prediction, 2 if a contrast (or unmatched or NULL), 3 if pairs
@@ -416,17 +478,22 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
     
     if(infer[1]) { # add CIs
         acv = .adj.critval(level, result$df, adjust, fam.info, side, corrmat)
-        adjust = acv$adjust
+        ###adjust = acv$adjust # in older versions, I forced same adj method for tests
         cv = acv$cv
         cv = switch(side + 2, cbind(-Inf, cv), cbind(-cv, cv), cbind(-cv, Inf))
         cnm = if (zFlag) c("asymp.LCL", "asymp.UCL") else c("lower.CL","upper.CL")
         result[[cnm[1]]] = result[[1]] + cv[, 1]*result$SE
         result[[cnm[2]]] = result[[1]] + cv[, 2]*result$SE
-        if (!is.null(link)) {
-            result[[cnm[1]]] = link$linkinv(result[[cnm[1]]])
-            result[[cnm[2]]] = link$linkinv(result[[cnm[2]]])
-        }
         mesg = c(mesg, paste("Confidence level used:", level), acv$mesg)
+        if (inv) {
+            clims = with(link, cbind(linkinv(result[[cnm[1]]]), linkinv(result[[cnm[2]]])))
+            tmp = apply(clims, 1, function(x) { 
+                z = diff(x); ifelse(is.na(z), 0, z) })
+            idx = if (all(tmp >= 0)) 1:2 else 2:1
+            result[[cnm[1]]] = clims[, idx[1]]
+            result[[cnm[2]]] = clims[, idx[2]]
+            mesg = c(mesg, paste("Intervals are back-transformed from the", link$name, "scale"))
+        }
     }
     if(infer[2]) { # add tests
         if (!all(null == 0)) {
@@ -454,18 +521,20 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
                                  "with a threshold of", delta))
         if(tail != 0) 
             mesg = c(mesg, paste("P values are ", ifelse(tail<0,"left-","right-"),"tailed", sep=""))
-        if (!is.null(link)) 
-            mesg = c(mesg, "Tests are performed on the linear-predictor scale")
+        if (inv) 
+            mesg = c(mesg, paste("Tests are performed on the", link$name, "scale"))
     }
-    if (!is.null(link)) {
-        result[["SE"]] = link$mu.eta(result[[1]]) * result[["SE"]]
-        result[[1]] = link$linkinv(result[[1]])
+    if (inv) {
+        result[["SE"]] = with(link, abs(mu.eta(result[[1]]) * result[["SE"]]))
+        result[[1]] = with(link, linkinv(result[[1]]))
     }
     
-    if (length(object@misc$avgd.over) > 0)
-        mesg = c(paste("Results are averaged over the levels of:",
+    if (length(object@misc$avgd.over) > 0) {
+        qual = attr(object@misc$avgd.over, "qualifier")
+        if (is.null(qual)) qual = ""
+        mesg = c(paste0("Results are averaged over", qual, " the levels of: ",
                        paste(object@misc$avgd.over, collapse = ", ")), mesg)
-    
+    }
     summ = cbind(lbls, result)
     attr(summ, "estName") = estName
     attr(summ, "clNames") = cnm  # will be NULL if infer[1] is FALSE
@@ -493,6 +562,7 @@ print.summary.ref.grid = function(x, ..., digits=NULL, quote=FALSE, right=TRUE)
     x.save = x
     if (!is.null(x$df)) x$df = round(x$df, 2)
     if (!is.null(x$t.ratio)) x$t.ratio = round(x$t.ratio, 3)
+    if (!is.null(x$z.ratio)) x$z.ratio = round(x$z.ratio, 3)
     if (!is.null(x$p.value)) {
         fp = x$p.value = format(round(x$p.value,4), nsmall=4, sci=FALSE)
         x$p.value[fp=="0.0000"] = "<.0001"
